﻿param
(
    [parameter(mandatory=$True)]
    [String[]]$HyperHostName
    
)

#Getting current execution path
$scriptpath = $MyInvocation.MyCommand.Path
$dir = Split-Path $scriptpath
$version = "This list was updated on January 24, 2016 by @ericberg_de"

#Loading list of updates from XML files

[xml]$SourceFileHyperV = Get-Content $dir\UpdatesListHyperV.xml
[xml]$SourceFileCluster = Get-Content $dir\UpdatesListCluster.xml

$HyperVHotfixes = $SourceFileHyperV.Updates.Update
$ClusterHotfixes = $SourceFileCluster.Updates.update

#Getting Hotfixes installed on the specified Hyper-V Host

foreach($VMHost in $HyperHostName)
{
$Hotfixes = Get-HotFix -ComputerName $VMHost |select HotfixID,description
Write-Host $version $HyperHostName -ForegroundColor Green
Write-Host "COLLECTING HOTFIXES ON HYPER-V HOST: " $HyperHostName -ForegroundColor Yellow
Write-Host "Listing Hyper-V 2012 R2 Hotfixes" -ForegroundColor Yellow
foreach($RecomendedHotfix in $HyperVHotfixes)
{
        $witness = 0
        foreach($hotfix in $Hotfixes)
        {
                If($RecomendedHotfix.id -eq $hotfix.HotfixID)
                {
                    Write-Host "--------------------------"
                    Write-Host "Hyper-V Host: "$VMHost
                    Write-Host $RecomendedHotfix.Id "installed" -ForegroundColor Green
                    write-host $RecomendedHotfix.Description
                    Write-Host "--------------------------"
                    $witness = 1
                 }
        }  
        if($witness -eq 0)
        {
            Write-Host "--------------------------"
            Write-Host "Hyper-V Host: "$VMHost
            Write-Host $RecomendedHotfix.Id "not installed" -ForegroundColor Red
            write-host $RecomendedHotfix.Description
            Write-Host "--------------------------"
        }

}

Write-Host "Listing Failover Cluster 2012 R2 Hotfixes" -ForegroundColor Yellow

foreach($RecomendedClusterHotfix in $ClusterHotfixes)
{
        $witness = 0
        foreach($hotfix in $Hotfixes)
        {
                If($RecomendedClusterHotfix.id -eq $hotfix.HotfixID)
                {
                    Write-Host "--------------------------"
                    Write-Host "Hyper-V Host: "$VMHost
                    Write-Host $RecomendedClusterHotfix.Id "installed" -ForegroundColor Green
                    write-host $RecomendedClusterHotfix.Description
                    Write-Host "--------------------------"
                    $witness = 1
                 }
        }  
        if($witness -eq 0)
        {
            Write-Host "--------------------------"
            Write-Host "Hyper-V Host: "$VMHost
            Write-Host $RecomendedClusterHotfix.Id "not installed" -ForegroundColor Red
            write-host $RecomendedClusterHotfix.Description
            Write-Host "--------------------------" 
        }
}
Write-Host $version $HyperHostName -ForegroundColor Green
}